{glossary-link term="finite state automaton"}finite state automaton{glossary-link end} (FSA) might seem strange, but each word is quite simple.
"Finite" just means that there is a limited number of states (such as train stations) in the map. The "state" is just as another name for the train stations we were using. "Automaton" is an old word meaning a machine that acts on its own, following simple rules (such as the cuckoo in a cuckoo clock).